<?php

namespace Drupal\nft_oembed\Normalizer;

use Drupal\media\OEmbed\Resource;
use Drupal\serialization\Normalizer\ContentEntityNormalizer;

/**
 * Converts NFT data from/to OEmbed-compliant values/object.
 */
class ResourceNormalizer extends ContentEntityNormalizer {

  /**
   * {@inheritdoc}
   */
  public function supportsNormalization($data, $format = NULL) {
    if (!is_object($data) || !$this->checkFormat($format)) {
      return FALSE;
    }

    if ($data instanceof Resource) {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function supportsDenormalization($data, $type, $format = NULL, array $context = []) {
    if (!$this->checkFormat($format)) {
      return FALSE;
    }

    // Not implemented yet.
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function normalize(Resource $resource, $format = NULL, array $context = []) {
    $normalized_values = [];

    $normalized_values['type'] = $resource->getType();
    $normalized_values['title'] = $resource->getTitle();
    $normalized_values['author_name'] = $resource->getAuthorName();
    $normalized_values['author_url'] = $resource->getAuthorUrl();
    $normalized_values['provider'] = $resource->getProvider();
    $normalized_values['thumbnail_url'] = $resource->getThumbnailUrl();
    $normalized_values['thumbnail_width'] = $resource->getThumbnailWidth();
    $normalized_values['thumbnail_height'] = $resource->getThumbnailHeight();
    $normalized_values['width'] = $resource->getWidth();
    $normalized_values['height'] = $resource->getHeight();
    $normalized_values['url'] = $resource->getUrl();
    $normalized_values['html'] = $resource->getHtml();

    return $normalized_values;
  }

  /**
   * {@inheritdoc}
   */
  public function denormalize($data, $format = NULL, array $context = []) {
    // @todo Find a way to create a new Resource object.
    // $entity = new Resource();
    // return $entity;

    return NULL;
  }

}
